@@ -3,26 +3,26 @@
 
       ===============================================================================================================================
       ===============================================================================================================================
-	  This file is part of "luckyBackup" project
-	  Copyright 2008-2010, Loukas Avgeriou
-	  luckyBackup is distributed under the terms of the GNU General Public License
-	  luckyBackup is free software: you can redistribute it and/or modify
-	  it under the terms of the GNU General Public License as published by
-	  the Free Software Foundation, either version 3 of the License, or
-	  (at your option) any later version.
-      
-	  luckyBackup is distributed in the hope that it will be useful,
-	  but WITHOUT ANY WARRANTY; without even the implied warranty of
-	  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	  GNU General Public License for more details.
-      
-	  You should have received a copy of the GNU General Public License
-	  along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
+        This file is part of "luckyBackup" project
+        Copyright 2008-2011, Loukas Avgeriou
+        luckyBackup is distributed under the terms of the GNU General Public License
+        luckyBackup is free software: you can redistribute it and/or modify
+        it under the terms of the GNU General Public License as published by
+        the Free Software Foundation, either version 3 of the License, or
+        (at your option) any later version.
+        
+        luckyBackup is distributed in the hope that it will be useful,
+        but WITHOUT ANY WARRANTY; without even the implied warranty of
+        MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+        GNU General Public License for more details.
+        
+        You should have received a copy of the GNU General Public License
+        along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
-      project version	: Please see "main.cpp" for project version
+        project version   : Please see "main.cpp" for project version
 
-      developer 		: luckyb 
-      last modified 		: 23 Aug 2010
+        developer         : luckyb 
+        last modified     : 08 Mar 2011
       ===============================================================================================================================
       ===============================================================================================================================
 */
@@ -99,7 +99,9 @@ void aboutDialog::setThanks()
 	uiA.textBrowser_Thanks -> setOpenExternalLinks(TRUE);
 
 	Text =	"<p align=\"center\"><b>" + tr("Tom Tryfonidis") + "</b><br>(thanos)<br>" +
-		tr("Arch linux package/pkgbuild official maintainer (AUR)") + "<br><br>"
+		tr("Arch linux package/pkgbuild official maintainer (AUR)") + "<br>" +
+		tr("Greek manual translator") + "<br>" +
+        tr("Valuable advisor") + "<br><br>"
 
 		"<b>" + tr("Yiorgos Kapellakis") + "</b><br>(slackware)<br>" +
 		tr("rpm packager, valuable tester and remote connections advisor") + "<br><br>"
@@ -124,10 +126,16 @@ void aboutDialog::setThanks()
 
 		"<b>" + tr("Jack Fink") + "</b><br>" +
 		tr("port to Mac OS X") + "<br><br>"
+		
+		 "<b>" + tr("Elbert Pol") + "</b><br>" +
+        tr("port to OS/2") + "<br><br>"
 
 		"<b>" + tr("Theo Chatzimichos") + "</b><br>" +
 		tr("Gentoo ebuild maintainer") + "<br><br>"
 		
+		"<b>" + tr("Dimitris Stasinopoulos") + "</b><br>(alfisti)<br>" + 
+        tr("Puppy pet & sfs maintainer") + "<br><br>"
+		
 		"<b>" + tr("Juan Luis Baptiste") + "</b><br>" +
 		tr("Mandriva package maintainer (official contrib repo)") + "<br><br>"
 
@@ -200,15 +208,19 @@ void aboutDialog::setThanks()
 		 "<b>" + tr("Michele Dall'Arno") + "</b><br>" +
 		tr("special guest bug killer ;)") + "<br><br>" +
 		
+		 "<b>" + tr("Aphofis Scott") + "</b><br>" +
+        tr("valuable tester & brainstorming specialist") + "<br><br>" +
+
+		
 		tr("...to all users of the ")+
-		"<br><a href=\"http://www.linuxformat.gr/\" target=\"_blank\">Hellenic Linuxformat</a>, "
-		"<a href=\"http://www.sidux.com/\" target=\"_blank\">sidux.com</a>, "
-		"<a href=\"http://www.sidux.gr/\" target=\"_blank\">sidux.gr</a>, "
+		"<br><a href=\"http://www.linuxinside.gr/\" target=\"_blank\">Linux Inside</a>, "
+		"<a href=\"http://www.aptosid.com/\" target=\"_blank\">aptosid.com</a>, "
+		"<a href=\"http://www.aptosid.gr/\" target=\"_blank\">aptosid.gr</a>, "
 		"<a href=\"http://forum.ubuntu-gr.org/\" target=\"_blank\">ubuntu.gr</a>, "
 		"<a href=\"http://forum.hellug.gr/\" target=\"_blank\">hellug</a>, "
 		"and <a href=\"http://www.kde-apps.org//\" target=\"_blank\">kde-apps.org</a><br>" +
 		tr("forums for their support.") + "<br><br>" +
-		tr("Especially") + "<br>alfisti, constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Carsten, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams, Felix, skevo, Philipp F, Christian Harms, Paul Hewlett, Tristan Gross, Fabian Muscariello, James Mohr and Julie Pierson<br>" +
+		tr("Especially") + "<br>constantinos, promeneur, grigris, dannys,marios, Regenwald, flo, Ilias Paraponiaris, Takis Vounatsos, Lieven Tytgat, mathetes, Johan Linde, Chris Sylvester, Manos Nikiforakis, Giorgos Katsikatsos, Ray Ambrosi, Barry Jackson, Damien Cassou, Carsten, Daniele Soldati Chris (slam), Paul Chapman, kingfame, Giorgos 'jeff' Finikianakis, Shelby Williams, Felix, skevo, Philipp F, Christian Harms, Paul Hewlett, Tristan Gross, Fabian Muscariello, James Mohr, Julie Pierson and Peter<br>" +
 		tr("that contributed to this project one way or another") + "<br><br>" +
 
 		tr("Last but no least") +":<br>"+
@@ -222,7 +234,7 @@ void aboutDialog::setLicense(QUrl licenseUrl)
 
 	licenseUrl.setScheme("file");
 
-	if (licenseUrl.toString() == "file:///Does_not_exist")
+	if (licenseUrl.toString(QUrl::RemoveScheme) == "Does_not_exist")
 		uiA.textBrowser_License -> setText(tr("Could not locate the license file") + "!!");
 	else
 		uiA.textBrowser_License -> setSource(licenseUrl);
