@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2010, Loukas Avgeriou
+     Copyright 2008-2011, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
      You should have received a copy of the GNU General Public License
      along with luckyBackup.  If not,see <http://www.gnu.org/licenses/>.
  developer 		: luckyb 
- last modified 		: 17 Oct 2010
+ last modified 		: 17 Feb 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -134,15 +134,15 @@ void commandline::rsyncIT()
 					QString tempSource = tempArguments[tempArguments.size()-2];
 					QString tempDestination = tempArguments[tempArguments.size()-1];
 					QString sourceLast = tempSource;
-					if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
+					if (!tempSource.endsWith(SLASH))	// this means task is of type "backup dir by name"
 					{
 						if (sourceLast.contains(":"))	// this is normal for a remote directory
 							sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-						if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
-							sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+						if (tempSource.contains(SLASH))	// this is normal for a directory unless it is remote
+							sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(SLASH)-1);	//this is the lowest dir of source
 						
-						tempSource.append("/");
-						tempDestination.append(sourceLast + "/");
+						tempSource.append(SLASH);
+						tempDestination.append(sourceLast + SLASH);
 					}
 					tempDestination.append (snapDefaultDir);
 					
@@ -158,7 +158,7 @@ void commandline::rsyncIT()
 					int snapToKeep = currentSnaps-maxSnaps + 1;
 					while ( snapToKeep < currentSnaps )
 					{
-						rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + "/");
+						rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + SLASH);
 						snapToKeep++;
 					}
 					
@@ -190,9 +190,9 @@ void commandline::rsyncIT()
 					rmProcess -> waitForFinished();
 					
 					if ((rmProcess -> exitCode()) == 0)
-						cout << "\nRemoved  all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/").toUtf8()).toStdString();
+						cout << "\nRemoved  all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + SLASH).toUtf8()).toStdString();
 					else
-						cout << "\nfailed to remove all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/").toUtf8()).toStdString() << "\n";
+						cout << "\nfailed to remove all older snapshots data";// << QString((tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + SLASH).toUtf8()).toStdString() << "\n";
 				// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 				
 					count = 0;
@@ -266,7 +266,7 @@ void commandline::rsyncIT()
 			
 			//pre-task commands execution ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 			count = 0;
-			bool beforeExitedWithError = FALSE;
+			bool StopTaskExecution = FALSE;
 			
 			while (Operation[currentOperation] -> GetExecuteBeforeListSize() > count)
 			{
@@ -289,8 +289,11 @@ void commandline::rsyncIT()
 				{
 					cout << "\nThe process failed to start\n";
 					errorCount++;
-					beforeExitedWithError = TRUE;
-					break;
+					if (Operation[currentOperation] -> GetExecuteBeforeListItemState(count) == TRUE) 
+                    {
+                        StopTaskExecution = TRUE;
+                        break;
+                    }
 				}
 				
 				cout << "\nexit code	: " << syncProcess -> exitCode();
@@ -298,8 +301,11 @@ void commandline::rsyncIT()
 				if (syncProcess -> exitCode() != 0)
 				{
 					errorCount++;
-					beforeExitedWithError = TRUE;
-					break;
+                    if (Operation[currentOperation] -> GetExecuteBeforeListItemState(count) == TRUE) 
+                    {
+                        StopTaskExecution = TRUE;
+                        break;
+                    }
 				}
 				
 				logFileUpdate("pre-finished", "", count);
@@ -308,7 +314,7 @@ void commandline::rsyncIT()
 			}
 			
 			//task execution
-			if (beforeExitedWithError)
+			if (StopTaskExecution)
 			{
 				logFileUpdate("pre-task-exited-with-error", "", 0);
 				
@@ -443,16 +449,38 @@ void commandline::rsyncIT()
 						{
 							cout << "\nThe process failed to start\n";
 							errorCount++;
+                            if (Operation[currentOperation] -> GetExecuteAfterListItemState(count) == TRUE)
+                            {
+                                StopTaskExecution = TRUE;
+                                break;
+                            }
 						}
 					
 						cout << "\nexit code	: " << syncProcess -> exitCode();
 						cout << "\nexit status	: " << syncProcess -> exitStatus() << "\n";
-						if (syncProcess -> exitCode() != 0)
-							errorCount++;
+                        if (syncProcess -> exitCode() != 0)
+                        {
+                            errorCount++;
+                            if (Operation[currentOperation] -> GetExecuteAfterListItemState(count) == TRUE)
+                            {
+                                StopTaskExecution = TRUE;
+                                break;
+                            }
+                        }
+						
 						logFileUpdate("post-finished", "", count);
 						
 						count++;
 					}
+					if (StopTaskExecution)
+                    {
+                        logFileUpdate("pre-task-exited-with-error", "", 0);
+                        
+                        cout << "\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
+                        cout << " Post-task command exited with an error. Skipping executing the rest of commands...";
+                        cout << "\n--------------------------------------------------------------------------------------------\n";
+                    }
+					
 				}
 			}
 			// close the logfile
@@ -473,8 +501,8 @@ void commandline::rsyncIT()
 					QString sourceLast = Operation[currentOperation] -> GetSource();
 					if (sourceLast.contains(":"))	// this is normal for a remote directory
 						sourceLast = sourceLast.right(sourceLast.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-					if (sourceLast.contains("/"))	// this is normal for a directory unless it is remote
-						sourceLast = sourceLast.right(sourceLast.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+					if (sourceLast.contains(SLASH))	// this is normal for a directory unless it is remote
+						sourceLast = sourceLast.right(sourceLast.size()-sourceLast.lastIndexOf(SLASH)-1);	//this is the lowest dir of source
 					
 					removeLimit = removeLimit + sourceLast.size()+1;
 				}
@@ -528,6 +556,27 @@ void commandline::thats_all()
 	cout << "============================================================================================\n";
 	
 	saveProfile(QString(currentProfile.toUtf8()));	// updates the execution time
+    
+    // send an email
+    if ( (!emailNever) && (!DryRun) )
+    {
+        bool send = TRUE;
+        if ( ((emailError) && (errorsFound == 0))   // do not send if the condition "error" is checked and there are no errors
+                ||
+             ((emailSchedule) && (!NoQuestions)) )  // do not send if the condition "scheduled" is checked
+                                                                   // & --no-questions is NOT given as argument
+            send = FALSE;
+        
+        // ***** gui mode and "schedule" is covered in executenow.cpp ******
+        
+        if (send)
+        {
+            cout << "\n\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n";
+            cout << "trying to send an email\n";
+            cout << "       . . .\n\n";
+            cout << sendEmailNow(FALSE).toStdString();
+        }
+    }
 }
 
 
