@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2010, Loukas Avgeriou
+     Copyright 2008-2011, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@
 
  project version	: Please see "main.cpp" for project version
 
- developer 		: luckyb 
- last modified 		: 18 Oct 2010
+ developer          : luckyb 
+ last modified      : 17 Feb 2011
 ===============================================================================================================================
 ===============================================================================================================================
  ********************************** DO NOT FORGET TO CHANGE "commandline.cpp:rsyncIT()" ********************************************************
@@ -36,152 +36,174 @@ QTime StartTime(0,0,0,0);	//find out elapsed time from these;
 // executes rsync (& other commands )and displays progress.
 void luckyBackupWindow::executeNOW ()
 {
-	NOWexecuting = TRUE;		//this is mainly used if the window close button (or alt+F4) is pressed
-	ABORTpressed = FALSE;		//becomes true if abort button pressed
-	//change gui to execute mode !!
-	guiModeNormal = FALSE;
-	
-	(ui.rsyncOutput->document())->setMaximumBlockCount(50000);	// set the maximum block count for the output window to avoid freezing
-	
-	swapGUI("execution");
-	ui.AbortButton -> setVisible (TRUE);
-	ui.DoneButton -> setVisible (FALSE);
-	ui.rsyncOutput -> setText("");
-	
-	outputString = "";
-	outputError = "";
-	calculating = FALSE;		//these 3 bools are used to diplay progress of rsync at the info window
-	transferring = FALSE;
-	deleting = FALSE;
-	ExecuteBefore=FALSE;
-	ExecuteBeforeExitedError = FALSE;
-	ExecuteAfter=FALSE;
-	writeToLog=FALSE;
-	errorsFound = 0;		//total error founds during profile execution
-	count = 0;
-	currentAfter = 0;
-	currentBefore = 0;
-	errorCount = 0;			//errors found during task execution
+    NOWexecuting = TRUE;		//this is mainly used if the window close button (or alt+F4) is pressed
+    ABORTpressed = FALSE;		//becomes true if abort button pressed
+    //change gui to execute mode !!
+    guiModeNormal = FALSE;
 
-	//initiate tray icon
-	if (QSystemTrayIcon::isSystemTrayAvailable ())
-	{
-		createTrayIcon();	//create the tray icon
-		LBtray -> show();	// show the tray icon
-	}
-	//display a popup baloon
-	trayMessage = 	tr("execution of profile:","tray message - execution of profile: <PROFILENAME> in progress...") + " " + 
-			profileName + " " + tr("in progress...","tray message - execution of profile: <PROFILENAME> in progress...");
-	if (DryRun)
-		trayMessage.append("\n(" + tr("simulation mode") + ")");
-	if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
-		LBtray -> showMessage (appName, trayMessage, QSystemTrayIcon::Information,3000);
-	
-	connect ( ui.AbortButton, SIGNAL( clicked() ), this, SLOT( abortPressed() ) );	//connect abort pushButton SLOT ----------------
-	connect ( ui.DoneButton, SIGNAL( clicked() ), this, SLOT( donePressed() ) );	//connect done pushButton SLOT ----------------
+    (ui.rsyncOutput->document())->setMaximumBlockCount(50000);	// set the maximum block count for the output window to avoid freezing
 
-	syncProcess = new QProcess(this);	//create a new qprocess (for rsync) & connect signals
-	connect(syncProcess, SIGNAL(readyReadStandardError()), this, SLOT(appendRsyncOutput()));
-	connect(syncProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(appendRsyncOutput()));
-	connect(syncProcess, SIGNAL (finished(int, QProcess::ExitStatus)), this, SLOT(procFinished()));
+    swapGUI("execution");
+    ui.AbortButton -> setVisible (TRUE);
+    ui.DoneButton -> setVisible (FALSE);
+    ui.rsyncOutput -> setText("");
 
-	if (silentMode)
-		minimizeTray();
-		
-	//rsync command & arguments initiation
-	command = "rsync";
-	rsyncArguments.clear();
-	syncAB = TRUE;
+    outputString = "";
+    outputError = "";
+    calculating = FALSE;		//these 3 bools are used to diplay progress of rsync at the info window
+    transferring = FALSE;
+    deleting = FALSE;
+    ExecuteBefore=FALSE;
+    ExecuteBeforeExitedError = FALSE;
+    ProcReportedError = FALSE;
+    StopTaskExecution = FALSE;
+    ExecuteAfter=FALSE;
+    writeToLog=FALSE;
+    errorsFound = 0;		//total error founds during profile execution
+    count = 0;
+    currentAfter = 0;
+    currentBefore = 0;
+    errorCount = 0;			//errors found during task execution
 
-	StartTime.start();	//start the timer to measure elapsed time
+    //initiate tray icon
+    if (QSystemTrayIcon::isSystemTrayAvailable ())
+    {
+        createTrayIcon();	//create the tray icon
+        LBtray -> show();	// show the tray icon
+    }
+    //display a popup baloon
+    trayMessage = 	tr("execution of profile:","tray message - execution of profile: <PROFILENAME> in progress...") + " " + 
+            profileName + " " + tr("in progress...","tray message - execution of profile: <PROFILENAME> in progress...");
+    if (DryRun)
+        trayMessage.append("\n(" + tr("simulation mode") + ")");
+    if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
+    {
+        if (KDErunning)
+        {
+            QProcess *dialogProcess;    dialogProcess = new QProcess(this);
+            QStringList dialogArgs;     dialogArgs << "--title" << appName << "--passivepopup" << trayMessage << "10";
+            dialogProcess -> start ("kdialog",dialogArgs);
+        }
+        else
+            LBtray -> showMessage (appName, trayMessage, QSystemTrayIcon::Information,3000);
+    }
+    //Initialize shhutdown button
+    ui.pushButton_shutdown -> setChecked(FALSE);
 
-	currentOperation = 0;
+    connect ( ui.AbortButton, SIGNAL( clicked() ), this, SLOT( abortPressed() ) );	//connect abort pushButton SLOT ----------------
+    connect ( ui.DoneButton, SIGNAL( clicked() ), this, SLOT( donePressed() ) );	//connect done pushButton SLOT ----------------
 
-	//increase currentOperation until first operation to be executed (execute tasks with a "by-pass WARNING option too)
-	while ( (currentOperation < TotalOperations) && (!Operation[currentOperation] -> GetPerform()) )
-			currentOperation++;
+    syncProcess = new QProcess(this);	//create a new qprocess (for rsync) & connect signals
+    connect(syncProcess, SIGNAL(readyReadStandardError()), this, SLOT(appendRsyncOutput()));
+    connect(syncProcess, SIGNAL(readyReadStandardOutput()), this, SLOT(appendRsyncOutput()));
+    connect(syncProcess, SIGNAL (finished(int, QProcess::ExitStatus)), this, SLOT(procFinished()));
+    connect(syncProcess, SIGNAL (error(QProcess::ProcessError)), this, SLOT(procError()));
 
-	executeBeforeTask();				//execute pre-task commands if any
+    if (silentMode)
+        minimizeTray();
+        
+    //rsync command & arguments initiation
+    command = "rsync";
+    rsyncArguments.clear();
+    syncAB = TRUE;
+
+    StartTime.start();	//start the timer to measure elapsed time
+
+    currentOperation = 0;
+
+    //increase currentOperation until first operation to be executed (execute tasks with a "by-pass WARNING option too)
+    while ( (currentOperation < TotalOperations) && (!Operation[currentOperation] -> GetPerform()) )
+            currentOperation++;
+
+    executeBeforeTask();				//execute pre-task commands if any
 }
 
 // swapGUI=====================================================================================================
 //swaps the gui mode from normal to execute
 void luckyBackupWindow::swapGUI(QString GUImode)
 {
-	if (GUImode == "execution")	//change gui to normal mode
-	{
-		ui.pushButton_start	-> setVisible (FALSE);
-		ui.listWidget_operations -> setVisible (FALSE);
-		ui.textBrowser_info	-> setVisible (FALSE);
-		ui.label_TaskList -> setText(tr("commands output","output window label"));
-		ui.frame_operations -> setToolTip(tr("rsync and pre/post task commands output is displayed here","tooltip"));
-		
-		ui.pushButton_up		-> setVisible (FALSE);
-		ui.pushButton_down		-> setVisible (FALSE);
-		ui.label_include	-> setVisible (FALSE);
-		ui.menuFile		-> setEnabled (FALSE);
-		ui.menu_Task		-> setEnabled (FALSE);
-		languageMenu		-> setEnabled (FALSE);
-		settingsMenu		-> setEnabled (FALSE);
-		helpMenu		-> setEnabled (FALSE);
-		profileToolbar		-> setEnabled (FALSE);
-		profileComboToolbar	-> setEnabled (FALSE);
-		ui.comboBox_profile	-> setEnabled (FALSE);
-		ui.groupBox_task	-> setVisible (FALSE);
-		ui.checkBox_DryRun	-> setEnabled (FALSE);
-		ui.pushButton_exit	-> setVisible (FALSE);
-		ui.label		-> setVisible (FALSE);
-	
-		ui.AbortButton 	-> setVisible (TRUE);
-		ui.DoneButton 	-> setVisible (TRUE);
-		ui.rsyncOutput 	-> setVisible (TRUE);
-		//ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
-		ui.nowDoing	-> setVisible (IsVisibleInfoWindow);
-		ui.OperationProgress -> setVisible (TRUE);
-		if (QSystemTrayIcon::isSystemTrayAvailable ())
-			ui.pushButton_minimizeToTray	-> setVisible (TRUE);
-		else
-			ui.pushButton_minimizeToTray	-> setVisible (FALSE);
-		ui.pushButton_nextError	-> setVisible (TRUE);
-		ui.pushButton_previousError	-> setVisible (TRUE);
-		ui.pushButton_nextError	-> setEnabled (FALSE);
-		ui.pushButton_previousError	-> setEnabled (FALSE);
-	}
-	else		//change gui to normal mode !!
-	{
-		ui.AbortButton 	-> setVisible (FALSE);
-		ui.DoneButton 	-> setVisible (FALSE);
-		ui.rsyncOutput 	-> setVisible (FALSE);
-		ui.nowDoing	-> setVisible (FALSE);
-		ui.OperationProgress -> setVisible (FALSE);
-		ui.pushButton_minimizeToTray	-> setVisible (FALSE);
-		ui.pushButton_nextError	-> setVisible (FALSE);
-		ui.pushButton_previousError	-> setVisible (FALSE);
-		
-		ui.pushButton_start	-> setVisible (TRUE);
-		ui.listWidget_operations -> setVisible (TRUE);
-		ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
-		ui.textBrowser_info	-> setVisible (IsVisibleInfoWindow);
-		ui.label_TaskList -> setText(tr("Task list","task list label"));
-		ui.frame_operations -> setToolTip(tr("List of all the available tasks","task list tooltip - line1")+"\n"+
-				tr("Use the 'include checkboxes' to include or not a selected task","task list tooltip - line2"));
-		
-		ui.pushButton_up	-> setVisible (TRUE);
-		ui.pushButton_down	-> setVisible (TRUE);
-		ui.label_include	-> setVisible (TRUE);
-		ui.menuFile		-> setEnabled (TRUE);
-		ui.menu_Task		-> setEnabled (TRUE);
-		languageMenu		-> setEnabled (TRUE);
-		settingsMenu		-> setEnabled (TRUE);
-		helpMenu		-> setEnabled (TRUE);
-		profileToolbar		-> setEnabled (TRUE);
-		profileComboToolbar	-> setEnabled (TRUE);
-		ui.comboBox_profile	-> setEnabled (TRUE);
-		ui.groupBox_task	-> setVisible (TRUE);
-		ui.checkBox_DryRun	-> setEnabled (TRUE);
-		ui.pushButton_exit	-> setVisible (FALSE);	// set this to true to make the exit button visible at normal mode
-		ui.label		-> setVisible (TRUE);
-	}
+    if (GUImode == "execution")	//change gui to execution mode
+    {
+        ui.pushButton_start	-> setVisible (FALSE);
+        ui.listWidget_operations -> setVisible (FALSE);
+        ui.textBrowser_info	-> setVisible (FALSE);
+        ui.label_TaskList -> setText(tr("commands output","output window label"));
+        ui.frame_operations -> setToolTip(tr("rsync and pre/post task commands output is displayed here","tooltip"));
+        
+        ui.pushButton_up    -> setVisible (FALSE);
+        ui.pushButton_down  -> setVisible (FALSE);
+        ui.label_include    -> setVisible (FALSE);
+        ui.menuFile         -> setEnabled (FALSE);
+        ui.menu_Task        -> setEnabled (FALSE);
+        languageMenu        -> setEnabled (FALSE);
+        settingsMenu        -> setEnabled (FALSE);
+        helpMenu            -> setEnabled (FALSE);
+        if (!runImmediately)
+            IsVisibleProfileToolbar = profileToolbar -> isVisible();//hold the visibility state of this toolbar
+        profileToolbar      -> setVisible (FALSE);
+        profileComboToolbar -> setEnabled (FALSE);
+        ui.comboBox_profile -> setEnabled (FALSE);
+        ui.groupBox_task    -> setVisible (FALSE);
+        ui.checkBox_DryRun  -> setEnabled (FALSE);
+        ui.pushButton_exit  -> setVisible (FALSE);
+        ui.label            -> setVisible (FALSE);
+
+        ui.AbortButton              -> setVisible (TRUE);
+        ui.DoneButton               -> setVisible (TRUE);
+        ui.rsyncOutput              -> setVisible (TRUE);
+        //ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
+        shutdownToolbar-> setVisible (TRUE);
+        if ( (KDErunning) || (currentUser == "super user") )
+            shutdownToolbar-> setEnabled (TRUE);
+        else
+            shutdownToolbar-> setEnabled (FALSE);
+        ui.nowDoing                 -> setVisible (IsVisibleInfoWindow);
+        ui.OperationProgress        -> setVisible (TRUE);
+        if (QSystemTrayIcon::isSystemTrayAvailable ())
+            ui.pushButton_minimizeToTray	-> setVisible (TRUE);
+        else
+            ui.pushButton_minimizeToTray	-> setVisible (FALSE);
+        ui.pushButton_nextError	-> setVisible (TRUE);
+        ui.pushButton_previousError	-> setVisible (TRUE);
+        ui.pushButton_nextError	-> setEnabled (FALSE);
+        ui.pushButton_previousError	-> setEnabled (FALSE);
+    }
+    else		//change gui to normal mode !!
+    {
+        ui.AbortButton              -> setVisible (FALSE);
+        ui.DoneButton               -> setVisible (FALSE);
+        ui.rsyncOutput              -> setVisible (FALSE);
+        ui.nowDoing                 -> setVisible (FALSE);
+        ui.OperationProgress        -> setVisible (FALSE);
+        ui.pushButton_minimizeToTray-> setVisible (FALSE);
+        ui.pushButton_nextError     -> setVisible (FALSE);
+        ui.pushButton_previousError -> setVisible (FALSE);
+        
+        ui.pushButton_start	-> setVisible (TRUE);
+        ui.listWidget_operations -> setVisible (TRUE);
+        ui.pushButton_InfoCollapse -> setChecked(!IsVisibleInfoWindow);
+        ui.textBrowser_info	-> setVisible (IsVisibleInfoWindow);
+        ui.label_TaskList -> setText(tr("Task list","task list label"));
+        ui.frame_operations -> setToolTip(tr("List of all the available tasks","task list tooltip - line1")+"\n"+
+                tr("Use the 'include checkboxes' to include or not a selected task","task list tooltip - line2"));
+        
+        ui.pushButton_up    -> setVisible (TRUE);
+        ui.pushButton_down  -> setVisible (TRUE);
+        ui.label_include    -> setVisible (TRUE);
+        ui.menuFile         -> setEnabled (TRUE);
+        ui.menu_Task        -> setEnabled (TRUE);
+        languageMenu        -> setEnabled (TRUE);
+        settingsMenu        -> setEnabled (TRUE);
+        helpMenu            -> setEnabled (TRUE);
+        profileToolbar      -> setVisible (IsVisibleProfileToolbar);
+        profileComboToolbar -> setEnabled (TRUE);
+        shutdownToolbar     -> setVisible (FALSE);
+        ui.comboBox_profile -> setEnabled (TRUE);
+        ui.groupBox_task    -> setVisible (TRUE);
+        ui.checkBox_DryRun  -> setEnabled (TRUE);
+        ui.pushButton_exit  -> setVisible (FALSE);	// set this to true to make the exit button visible at normal mode
+        ui.label            -> setVisible (TRUE);
+    }
 }
 
 // done button pressed=====================================================================================================
@@ -331,7 +353,7 @@ void luckyBackupWindow::executeBeforeTask()
 	if (ABORTpressed)		//better safe than sorry ;)
 		return;
 	
-	// logfile actions if real run is performed
+	// logfile & older snapshots actions if real run is performed
 	if ( (!DryRun) && (currentBefore == 0) )
 	{
 		int maxSnaps = Operation[currentOperation] -> GetKeepSnapshots();	// this is the number of snapshots to keep
@@ -359,15 +381,15 @@ void luckyBackupWindow::executeBeforeTask()
 			QString tempSource = tempArguments[tempArguments.size()-2];
 			QString tempDestination = tempArguments[tempArguments.size()-1];
 			QString sourceLast = tempSource;
-			if (!tempSource.endsWith("/"))	// this means task is of type "backup dir by name"
+			if (!tempSource.endsWith(SLASH))	// this means task is of type "backup dir by name"
 			{
 				if (sourceLast.contains(":"))	// this is normal for a remote directory
 					sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-				if (tempSource.contains("/"))	// this is normal for a directory unless it is remote
-					sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+				if (tempSource.contains(SLASH))	// this is normal for a directory unless it is remote
+					sourceLast = sourceLast.right(tempSource.size()-sourceLast.lastIndexOf(SLASH)-1);	//this is the lowest dir of source
 				
-				tempSource.append("/");
-				tempDestination.append(sourceLast + "/");
+				tempSource.append(SLASH);
+				tempDestination.append(sourceLast + SLASH);
 			}
 			tempDestination.append (snapDefaultDir);
 			
@@ -385,7 +407,7 @@ void luckyBackupWindow::executeBeforeTask()
 			int snapToKeep = currentSnaps-maxSnaps + 1;
 			while ( snapToKeep < currentSnaps )
 			{
-				rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + "/");
+				rmArgs.append("--filter=protect " + Operation[currentOperation] -> GetSnapshotsListItem(snapToKeep) + SLASH);
 				snapToKeep++;
 			}
 			
@@ -416,9 +438,9 @@ void luckyBackupWindow::executeBeforeTask()
 			rmProcess -> waitForFinished();
 			
 			if ((rmProcess -> exitCode()) == 0)
-				ui.rsyncOutput->append("\n" + tr("Removed all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
+				ui.rsyncOutput->append("\n" + tr("Removed all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + SLASH);
 			else
-				ui.rsyncOutput->append("\n" + tr("failed to remove all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + "/");
+				ui.rsyncOutput->append("\n" + tr("failed to remove all older snapshots data"));// +" " + tempDestination + Operation[currentOperation] -> GetSnapshotsListItem(0) + SLASH);
 			
 			//******************************************************
 		
@@ -479,10 +501,10 @@ void luckyBackupWindow::executeBeforeTask()
 	}
 
 	errorCount = 0;		// task starts, so set this to 0 no matter dry or real run
-	
+
 	// execute commands before task -----------------------------------------------------------------------------------------------------
 	//if there are no (more) pre-task commands to be executed || the previous pre-task command exited with an error
-	if ( (Operation[currentOperation] -> GetExecuteBeforeListSize() == currentBefore) || (ExecuteBeforeExitedError) )
+	if ( (Operation[currentOperation] -> GetExecuteBeforeListSize() == currentBefore) || (StopTaskExecution) )
 	{
 		currentBefore = 0;
 		ExecuteBefore=FALSE;
@@ -493,12 +515,18 @@ void luckyBackupWindow::executeBeforeTask()
 	{
 		ExecuteBefore=TRUE;
 		ExecuteBeforeExitedError = FALSE;
+        StopTaskExecution = FALSE;
+        ProcReportedError = FALSE;      // This might change as soon as syncprocess will start ()
 		outputInsert = logFileUpdate("pre-starting","",currentBefore);
 
 		ui.rsyncOutput->append(outputInsert);
 
 		syncProcess -> start (Operation[currentOperation] -> GetExecuteBeforeListItem(currentBefore));
-//		syncProcess -> waitForFinished();
+		syncProcess -> waitForStarted(5000);
+        
+        // The reason for the below jump is that when a process reports an error it does not emit finished() signals neither std output/errors
+        if (ProcReportedError)
+            procFinished();
 	}
 }
 
@@ -509,8 +537,8 @@ void luckyBackupWindow::executeAfterTask()
 		return;
 	
 	// execute commands after task -----------------------------------------------------------------------------------------------------
-	//if there are no (more) post-task commands to be executed or we are here because a pre-task command exited with an error or destination could not be created
-	if ( (Operation[currentOperation] -> GetExecuteAfterListSize() == currentAfter) || (ExecuteBeforeExitedError) || (DestCreateFail) )
+	//if there are no (more) post-task commands to be executed or we are here because a pre/post-task command exited with an error or destination could not be created
+	if ( (Operation[currentOperation] -> GetExecuteAfterListSize() == currentAfter) || (DestCreateFail) || (StopTaskExecution) )
 	{
 		if (!DryRun)
 		{
@@ -544,31 +572,38 @@ void luckyBackupWindow::executeAfterTask()
 			}
 		}
 
-		currentAfter = 0;
-		ExecuteAfter=FALSE;
+        currentAfter = 0;
+        ExecuteAfter=FALSE;
 
-		errorCount = 0;		// reset the current task error count
+        errorCount = 0;		// reset the current task error count
 
-		currentOperation++;
-		//increase currentOperation until next operation to be executed or end of operations
-		while ( (currentOperation < TotalOperations) && (!Operation[currentOperation] -> GetPerform()) )
-			currentOperation++;
-		if (currentOperation < TotalOperations)
-		{
-			ExecuteBeforeExitedError = FALSE;
-			executeBeforeTask();
-		}
-		else
-			setNowDoing();
-	}
-	else
-	{
-		ExecuteAfter=TRUE;
-		outputInsert = logFileUpdate("post-starting", "", currentAfter);
-		ui.rsyncOutput->append(outputInsert);
+        currentOperation++;
+        //increase currentOperation until next operation to be executed or end of operations
+        while ( (currentOperation < TotalOperations) && (!Operation[currentOperation] -> GetPerform()) )
+            currentOperation++;
+        if (currentOperation < TotalOperations)
+        {
+            ExecuteBeforeExitedError = FALSE;
+            StopTaskExecution = FALSE;
+            executeBeforeTask();
+        }
+        else
+            setNowDoing();
+    }
+    else
+    {
+        ExecuteAfter=TRUE;
+        ProcReportedError = FALSE;  // This might change as soon as syncprocess will start ()
+        outputInsert = logFileUpdate("post-starting", "", currentAfter);
+        ui.rsyncOutput->append(outputInsert);
 
-		syncProcess -> start (Operation[currentOperation] -> GetExecuteAfterListItem(currentAfter));
-	}
+        syncProcess -> start (Operation[currentOperation] -> GetExecuteAfterListItem(currentAfter));
+        syncProcess -> waitForStarted(5000);
+        
+        // The reason for the below jump is that when a process reports an error it does not emit finished() signals neither std output/errors
+        if (ProcReportedError)
+            procFinished();
+    }
 }
 
 //executes rsync  ===============================================================================================
@@ -577,12 +612,12 @@ void luckyBackupWindow::executeRsync()
 	if (ABORTpressed)		//better safe than sorry :)
 		return;
 	
-	if (ExecuteBeforeExitedError)	// if a pre-task command exited with an error do not do anything
+	if (StopTaskExecution)	// if a pre-task command exited with an error do not do anything
 	{
 		procFinished();
 		return;
 	}
-	
+
 	sync = Operation[currentOperation] -> GetTypeSync();		//set sync variable according to checkstate of radiobutton operation type
 	rsyncArguments = AppendArguments(Operation[currentOperation]);	//set rsync arguments
 	
@@ -644,8 +679,14 @@ void luckyBackupWindow::executeRsync()
 	//set the progressbar to 0
 	ui.OperationProgress -> setRange(0,100);
 	ui.OperationProgress -> setValue (0);
+    
+    ProcReportedError = FALSE;      // This might change as soon as syncprocess will start ()
 
 	syncProcess -> start (command,rsyncArguments);	// execute rsync command with rsyncArguments
+    
+    // The reason for the below jump is that when a process reports an error it does not emit finished() signals neither std output/errors
+    if (ProcReportedError)
+        procFinished();
 }
 
 //when rsyncProcess emits finished signal execute another RsyncProcess if any left====================================================================
@@ -653,18 +694,25 @@ void luckyBackupWindow::procFinished()
 {
 	if (ABORTpressed) //this is to prevent segmentation fault when abort button pressed
 		return;
-				
+
 	if (ExecuteBefore)		// if the pre-task execution command (process) finished
 	{
 		outputInsert = logFileUpdate("pre-finished", "", currentBefore);
 		ui.rsyncOutput->append(outputInsert);
-		if (syncProcess -> exitCode() != 0)	// if the pre-task command exited with an error
+        // if the pre-task command exited with an error AND the box is checked
+		if ( ((syncProcess -> exitCode() != 0) || (ProcReportedError)) && (Operation[currentOperation] -> GetExecuteBeforeListItemState(currentBefore) == TRUE) )
+        {
+            StopTaskExecution = TRUE;
 			ExecuteBeforeExitedError = TRUE;
+        }
 		else
+        {
 			ExecuteBeforeExitedError = FALSE;
+            StopTaskExecution = FALSE;
+        }
 		currentBefore++; 	//go to the next pre-task execution command 
-
 		executeBeforeTask();	//and executeBeforeTask again
+
 		return;
 	}
 
@@ -672,6 +720,15 @@ void luckyBackupWindow::procFinished()
 	{
 		outputInsert = logFileUpdate("post-finished", "", currentAfter);
 		ui.rsyncOutput->append(outputInsert);
+        // if the post-task command exited with an error AND the box is checked
+        if ( ((syncProcess -> exitCode() != 0) || (ProcReportedError)) && (Operation[currentOperation] -> GetExecuteAfterListItemState(currentAfter) == TRUE) )
+        {
+            StopTaskExecution = TRUE;
+            outputInsert = logFileUpdate("pre-task-exited-with-error", "", 0);
+            ui.rsyncOutput->append(outputInsert);
+        }
+        else
+            StopTaskExecution = FALSE;
 		currentAfter++; 		//go to the next post-task execution command 
 
 		executeAfterTask();		//and executeAfterTask again
@@ -679,7 +736,7 @@ void luckyBackupWindow::procFinished()
 	}
 
 	//display a couple of lines to indicate end of task
-	if (ExecuteBeforeExitedError)
+	if (StopTaskExecution)
 		outputInsert = logFileUpdate("pre-task-exited-with-error", "", 0);
 	else
 	{
@@ -698,6 +755,33 @@ void luckyBackupWindow::procFinished()
 		executeAfterTask();	//execute post-task commands (if any)
 }
 
+// A process reported an error (eg failed to start or crashed etc)
+void luckyBackupWindow::procError()
+{
+    ProcReportedError = TRUE;
+    QProcess::ProcessError commandError = syncProcess -> error();
+    QString errorText = tr("Unknown error");
+    switch (commandError)
+    {
+        case QProcess::FailedToStart: errorText = tr("Failed to start","this refers to a process");
+        break;
+        case QProcess::Crashed      : errorText = tr("Crashed","this refers to a process");
+        break;
+        case QProcess::Timedout     : errorText = tr("Timed out","this refers to a process");
+        break;
+        case QProcess::WriteError   : errorText = tr("Write error","this refers to a process");
+        break;
+        case QProcess::ReadError    : errorText = tr("Read error","this refers to a process");
+        break;
+        case QProcess::UnknownError : errorText = tr("Unknown error","this refers to a process");
+        break;
+    }
+    
+    errorsFound++;
+    errorCount++;
+    ui.rsyncOutput->append(logFileUpdate("process-reported-error", errorText, 0));
+    setNowDoing();    
+}
 //update dialog with new data (text - progressbar) - also update logfile =======================================================================
 void luckyBackupWindow::appendRsyncOutput()
 {
@@ -829,6 +913,7 @@ void luckyBackupWindow::setNowDoing()
 				nowDoingText.append(tr("deleting files")+": " + outputString);
 		}
 	}
+	
 	if ( (currentOperation == TotalOperations) && (!ABORTpressed))	//if all operations finished normally - not aborted
 	{
 		NOWexecuting = FALSE;		//this is mainly used if the window close button (or alt+F4) is pressed
@@ -867,12 +952,24 @@ void luckyBackupWindow::setNowDoing()
 		//update tray baloon
 		if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
 		{
-			LBtray -> showMessage (appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") , trayMessage, 
+            if (KDErunning)
+            {
+                QProcess *dialogProcess;    dialogProcess = new QProcess(this);
+                QStringList dialogArgs;
+                dialogArgs << "--title" << appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") << "--passivepopup" << trayMessage << "10";
+                dialogProcess -> start ("kdialog",dialogArgs);
+            }
+            else
+                LBtray -> showMessage (appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") , trayMessage, 
 													QSystemTrayIcon::Information,3000);
 			actionAbort	-> setVisible(FALSE);
 		}
 
 		finishUp();
+        
+        // bring the system down if the relevant button is pressed
+        if (ui.pushButton_shutdown -> isChecked())
+            shutDownSystem();
 		
 		if ( (silentMode) && (isMinimizedToTray == TRUE) )		// if --silent is given as argument and the gui is not shown exit the app
 		{
@@ -887,6 +984,7 @@ void luckyBackupWindow::setNowDoing()
 			exit(0);	//quit
 		}
 	}
+	
 	if (ABORTpressed)	//if operations were terminated by user
 	{
 		NOWexecuting = FALSE;		//this is mainly used if the window close button (or alt+F4) is pressed
@@ -906,7 +1004,15 @@ void luckyBackupWindow::setNowDoing()
 		//update tray baloon
 		if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
 		{
-			LBtray -> showMessage (appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") , trayMessage, 
+            if (KDErunning)
+            {
+                QProcess *dialogProcess;    dialogProcess = new QProcess(this);
+                QStringList dialogArgs;
+                dialogArgs << "--title" << appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") << "--passivepopup" << trayMessage << "10";
+                dialogProcess -> start ("kdialog",dialogArgs);
+            }
+            else
+                LBtray -> showMessage (appName + " - " + tr("execution of profile:") + " " + profileName + " " + tr("finished") , trayMessage, 
 															QSystemTrayIcon::Information,3000);
 			actionAbort	-> setVisible(FALSE);
 		}
@@ -958,16 +1064,78 @@ void luckyBackupWindow::finishUp()
 	{
 		//save the profile to update last execution times & no of errors
 		if (!saveProfile(currentProfile))
+        {
 			savedProfile = FALSE;
+            ui.actionSave -> setEnabled(TRUE);
+        }
 		else
+        {
 			savedProfile = TRUE;			//change profile status to "saved"
+			ui.actionSave -> setEnabled(FALSE);
+        }
 			
 		logfile.close();			// close the logfile
+        
+        // send an email
+        if ( (!ABORTpressed) && (!emailNever) )
+        {
+            bool send = TRUE;
+            if ( ((emailError) && (errorsFound == 0))   // do not send if the condition "error" is checked and there are no errors
+                    ||
+                 ((emailSchedule) && (!silentMode)) )  // do not send if the condition "scheduled" is checked and profile is not run in silent mode
+                
+                send = FALSE;
+            
+            // ***** console mode and "schedule" is covered in commandline.cpp ******
+            
+            if (send)
+            {
+                ui.rsyncOutput->append("<font color=green>~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~</font>");
+                ui.rsyncOutput->append(tr(  "trying to send an email"));
+                ui.rsyncOutput->append(     "       . . .");
+                ui.rsyncOutput->append(sendEmailNow(FALSE));
+            }
+        }
 	}
+	
+	shutdownToolbar-> setEnabled (FALSE);
 
 	// TESTING-TESTING-TESTING-TESTING-TESTING-TESTING
 	//QMessageBox::information(this, "LB","QtextDocument title= **" + ui.rsyncOutput->documentTitle() +"**");
 }
+
+// function shutDownSystem=====================================================================================================
+// shutdown the system if the relevant button is pressed, when all tasks are finished
+void luckyBackupWindow::shutDownSystem()
+{
+    QProcess *shutdownProcess;
+    shutdownProcess = new QProcess(this);
+    QString shutdownCommand="";    QStringList shutdownArgs;    shutdownArgs.clear();
+    
+    if (KDErunning)
+    {
+        shutdownCommand = "/usr/bin/qdbus";
+        shutdownArgs << "org.kde.ksmserver" << "/KSMServer" << "org.kde.KSMServerInterface.logout" << "1" << "2" << "2";
+    }
+    else if (currentUser == "super user")
+    {
+        shutdownCommand = "/sbin/shutdown";
+        shutdownArgs << "-h" << "1";
+        if ( (QSystemTrayIcon::isSystemTrayAvailable ()) && (QSystemTrayIcon::supportsMessages ()) )
+            LBtray -> showMessage (appName + " - " + tr("WARNING"), tr("The system will shutdown in 1 minute"), QSystemTrayIcon::Information,3000);
+    }
+    
+    shutdownProcess -> start (shutdownCommand,shutdownArgs);
+    
+    //delay the app exit for 3 seconds
+    QTime StartSleep(0,0,0,0);
+    StartSleep.start();
+    int elapsedSleepMsec = 0;
+    while (elapsedSleepMsec < 3000)
+        elapsedSleepMsec = StartSleep.elapsed();
+    exit(0);    //quit
+}
+
 // previous error button pressed=====================================================================================================
 void luckyBackupWindow::previousErrorJump()
 {
