@@ -4,7 +4,7 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 ===============================================================================================================================
 ===============================================================================================================================
     This file is part of "luckyBackup" project
-    Copyright 2008-2010, Loukas Avgeriou
+    Copyright 2008-2011, Loukas Avgeriou
     luckyBackup is distributed under the terms of the GNU General Public License
     luckyBackup is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +22,8 @@ cpp file that does all stuff needed when a signal is transmitted (eg button pres
 
 project version	: Please see "main.cpp" for project version
 
-developer 	: luckyb 
-last modified 	: 01 Sep 2010
+developer       : luckyb 
+last modified   : 22 Feb 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -40,6 +40,7 @@ last modified 	: 01 Sep 2010
 #include "modifyDialog.cpp"
 #include "helpBrowser.cpp"
 #include "scheduleDialog.cpp"
+#include "emailDialog.cpp"
 #include "about.cpp"
 #include "manage.cpp"
 #include "functions.cpp"
@@ -111,21 +112,22 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 
 	// Connections ----------------------------------------------------------------------------------------------------------
 	connect ( ui.pushButton_exit, SIGNAL( clicked() ), this, SLOT( exitApp() ) );		//pushbutton exit
-	connect( ui.actionQuit, SIGNAL(triggered()), this, SLOT(exitApp()));			//menu action quit
+	connect ( ui.actionQuit, SIGNAL(triggered()), this, SLOT(exitApp()));			//menu action quit
 
-	connect( ui.comboBox_profile, SIGNAL(currentIndexChanged (const int) ), this, SLOT(profileComboChanged()));
+	connect ( ui.comboBox_profile, SIGNAL(currentIndexChanged (const int) ), this, SLOT(profileComboChanged()));
 
-	connect( ui.actionNew, SIGNAL(triggered()), this, SLOT(NewProfile()));			//menu action newProfile
-	connect( ui.actionRename, SIGNAL(triggered()), this, SLOT(renameCurrentProfile()));	//menu action renameProfile
-	connect( ui.actionSave, SIGNAL(triggered()), this, SLOT(savePressed()));		//menu action saveProfile
+	connect ( ui.actionNew, SIGNAL(triggered()), this, SLOT(NewProfile()));			//menu action newProfile
+	connect ( ui.actionRename, SIGNAL(triggered()), this, SLOT(renameCurrentProfile()));	//menu action renameProfile
+	connect ( ui.actionSave, SIGNAL(triggered()), this, SLOT(savePressed()));		//menu action saveProfile
 	connect ( ui.actionSchedule, SIGNAL( triggered() ), this, SLOT( schedule() ) );		//action schedule
+    connect ( ui.actionEmail, SIGNAL( triggered() ), this, SLOT( email() ) );     //action email
 	connect ( ui.actionRefresh, SIGNAL( triggered() ), this, SLOT( refreshList() ) );	//action refresh (task list)
 	connect ( ui.actionDelete, SIGNAL( triggered() ), this, SLOT( deleteCurrentProfile() ) );	//action delete (currentProfile)
 	connect ( ui.actionDefault, SIGNAL( triggered() ), this, SLOT( setDefaultProfile() ) );	//action default (set currentProfile as default)
 	connect ( ui.actionImport, SIGNAL( triggered() ), this, SLOT( importProfile() ) );	//action import profile
 	connect ( ui.actionExport, SIGNAL( triggered() ), this, SLOT( exportProfile() ) );	//action export profile
 	connect ( ui.actionDuplicate_Profile, SIGNAL( triggered() ), this, SLOT( duplicateProfile() ) ); //action duplicate profile
-	connect( ui.actionDescription, SIGNAL(triggered()), this, SLOT(changeProfileDescription()));	//menu action changeProfileDescription
+	connect ( ui.actionDescription, SIGNAL(triggered()), this, SLOT(changeProfileDescription()));	//menu action changeProfileDescription
 	
 	connect ( ui.action_TaskAdd, SIGNAL( triggered() ), this, SLOT( add() ) ); 			//action add task
 	connect ( ui.action_TaskModify, SIGNAL( triggered() ), this, SLOT( modify() ) ); 		//action modify task
@@ -134,8 +136,8 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 	connect ( ui.action_TaskCreateRestore, SIGNAL( triggered() ), this, SLOT( AlsoCreateRestore() ) ); 	//action create restore
 	connect ( ui.action_TaskManageBackup, SIGNAL( triggered() ), this, SLOT( manage() ) ); 		//action manage backup
 	
-	connect (ui.pushButton_add, SIGNAL (clicked() ), this, SLOT(add()));			//pushbutton create (task)
-	connect (ui.pushButton_edit, SIGNAL (clicked() ), this, SLOT(modify()));		//pushbutton modify (task)
+	connect ( ui.pushButton_add, SIGNAL (clicked() ), this, SLOT(add()));			//pushbutton create (task)
+	connect ( ui.pushButton_edit, SIGNAL (clicked() ), this, SLOT(modify()));		//pushbutton modify (task)
 	connect ( ui.pushButton_remove, SIGNAL( clicked() ), this, SLOT( remove() ) );		//pushbutton remove (task)
 	connect ( ui.pushButton_up, SIGNAL( clicked() ), this, SLOT( moveUp() ) );		//pushbutton up
 	connect ( ui.pushButton_down, SIGNAL( clicked() ), this, SLOT( moveDown() ) );		//pushbutton down
@@ -164,7 +166,12 @@ luckyBackupWindow::luckyBackupWindow(QMainWindow *parent) : QMainWindow(parent)
 
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	InfoData.append("<p align=\"center\"><font color=magenta><b>" + tr("Welcome to","full phrase: 'Welcome to luckyBackup'") +" "
-	+ appName + ", " + currentUser + " :-)</font></b></p>");
+	+ appName);
+    if (OS2running)
+        InfoData.append(" :-)</font></b></p>");
+    else
+        InfoData.append(", " + currentUser + " :-)</font></b></p>");
+    
 	if (create == 0)
 		InfoData.append(loadData);
 	else
@@ -242,14 +249,18 @@ void luckyBackupWindow::profileComboChanged()
 // SLOT to lock the toolbars in their position
 void luckyBackupWindow::setToolbarAttrs()
 {
-	profileComboToolbar -> setFloatable(!actionLockToolbars->isChecked());
-	profileComboToolbar -> setMovable(!actionLockToolbars->isChecked());
-	profileStartToolbar -> setFloatable(!actionLockToolbars->isChecked());
-	profileStartToolbar -> setMovable(!actionLockToolbars->isChecked());
-	profileToolbar -> setFloatable(!actionLockToolbars->isChecked());
-	profileToolbar -> setMovable(!actionLockToolbars->isChecked());
-
-	AreToolbarsLocked = actionLockToolbars->isChecked();
+    AreToolbarsLocked = actionLockToolbars->isChecked();
+    
+	profileComboToolbar -> setFloatable(!AreToolbarsLocked);
+	profileComboToolbar -> setMovable(!AreToolbarsLocked);
+	profileStartToolbar -> setFloatable(!AreToolbarsLocked);
+	profileStartToolbar -> setMovable(!AreToolbarsLocked);
+	profileToolbar -> setFloatable(!AreToolbarsLocked);
+	profileToolbar -> setMovable(!AreToolbarsLocked);
+    
+    shutdownToolbar -> setVisible (FALSE);
+    shutdownToolbar -> setFloatable(!AreToolbarsLocked);
+    shutdownToolbar -> setMovable(!AreToolbarsLocked);
 
 	IsVisibleToolbarText = actionVisibleToolbarText -> isChecked();
 	if (IsVisibleToolbarText)
@@ -412,6 +423,13 @@ void luckyBackupWindow::renameCurrentProfile()
 	
 	InfoData.append(" <b>" + profileName + "</b><br>...<font color=green>"	+ tr("renamed successfully to",
 		"full phrase: '(default) profile <PROFILENAME> renamed successfully to <NEWPROFILENAME>'") + "</font> <b>" + newProfileName +"</b>");
+    
+    // update all relevant snap .changes as well as log files
+    if (arrangeLogSnap(1,"rename",newProfileName))
+        InfoData.append("<br><br>" + tr("All relevant files (logs etc) have also been updated"));
+    else
+        InfoData.append("<br><br>" + tr("Failed to update all relevant files (logs etc)"));
+    
 	setCurrentProfile(newProfile);
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	loadCurrentProfile();	// load the current profile
@@ -455,6 +473,12 @@ void luckyBackupWindow::deleteCurrentProfile()
 				": <b>" + profileName + "</b><br>...<font color=green>" +
 				tr("deleted successfully","full phrase: 'Profile <PROFILENAME> deleted successfully'") + " !!</font><br>");
 
+        // delete all relevant snap .changes as well as log files
+        if (arrangeLogSnap(1,"delete",profileName))
+            InfoData.append("<br>" + tr("All relevant files (logs etc) have also been deleted") + "<br>");
+        else
+            InfoData.append("<br>" + tr("Failed to delete all relevant files (logs etc)") + "<br>");
+    
 		// Load the default profile
 		setCurrentProfile(defaultProfile);	// set the defaultProfile as current
 		int create = createCurrentProfile();	// if it does not exist create it
@@ -491,7 +515,7 @@ void luckyBackupWindow::exportProfile()
 
 	// Display a save dialog
 	QString exportProfileName = QFileDialog::getSaveFileName(this,
-			appName + " - " + tr("Export Profile","this is a dialog title"), "/"+profileName+".profile",
+			appName + " - " + tr("Export Profile","this is a dialog title"), SLASH+profileName+".profile",
 			appName + " " + tr("profile")+" (*.profile)");
 	if ( exportProfileName == "")	//if cancel is pressed at the file dialog, do nothing
 		return;
@@ -591,6 +615,12 @@ void luckyBackupWindow::duplicateProfile()
 		+ tr("duplicated successfully as","full phrase: 'Profile <PROFILENAME> duplicated successfully as <FILENAME>'") +
 		"</font> <b>" + duplicateProfileName +"</b>");
 	
+    // duplicate all relevant snap .changes as well as log files
+    if (arrangeLogSnap(1,"duplicate",duplicateProfileName))
+        InfoData.append("<br><br>" + tr("All relevant files (logs etc) have also been duplicated"));
+    else
+        InfoData.append("<br><br>" + tr("Failed to duplicate all relevant files (logs etc)"));
+        
 	setCurrentProfile(currentProfile);		//reset all currentProfile variables
 	createProfileCombo();	// update the profile combobox with all existing profiles and set index to currentProfile
 	ui.textBrowser_info -> setText(InfoData);	//update the info window
@@ -620,6 +650,7 @@ void luckyBackupWindow::changeProfileDescription()
 	
 	ui.textBrowser_info -> setText(InfoData);	//update the info window
 	savedProfile = FALSE;			//change profile status to "unsaved"
+	ui.actionSave -> setEnabled(TRUE);
 }
 
 // duplicateTask ================================================================================================================================
@@ -672,10 +703,15 @@ void luckyBackupWindow::duplicateTask()
 	ui.listWidget_operations -> currentItem() -> setCheckState(Qt::Unchecked);
 	TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
 
-	modify();	//open the modify dialog for the new task
+    bool saveOrNot=FALSE;
+	modify();	//open the modify dialog for the new task, FALSE == do not save the result
+    saveOrNot = TRUE;
 
 	if (modifyOK)
+    {
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
+    }
 	else
 	{
 		//remove already created DUPLICATE TASK from operations list
@@ -731,8 +767,8 @@ void luckyBackupWindow::AlsoCreateRestore()
 
 	if (Operation[currentOperation] -> GetTypeDirName())
 	{
-		sourceDir.append(destDir.right(destDir.size() - destDir.lastIndexOf("/") - 1));
-		destDir.chop(destDir.size() - destDir.lastIndexOf("/") - 1);
+		sourceDir.append(destDir.right(destDir.size() - destDir.lastIndexOf(SLASH) - 1));
+		destDir.chop(destDir.size() - destDir.lastIndexOf(SLASH) - 1);
 	}
 
 	Operation[currentOperation] -> SetSource (sourceDir);
@@ -753,13 +789,16 @@ void luckyBackupWindow::AlsoCreateRestore()
 	textdialogW.exec();
 
 	modifyConnected = TRUE;
-	modify();	//open the modify dialog for the new operation to make sure everything is ok
+    saveOrNot = FALSE;
+	modify();	//open the modify dialog for the new operation to make sure everything is ok, FALSE == do not save the result
+    saveOrNot = TRUE;
 
 	if (modifyOK)		//connect the operation with its RESTORE duplicate
 	{
 		Operation[currentOperation] -> SetConnectRestore(Operation[oldCurrentOperation] -> GetName());	
 		Operation[oldCurrentOperation] -> SetConnectRestore(Operation[currentOperation] -> GetName());
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
 	}
 	else
 	{
@@ -775,7 +814,7 @@ void luckyBackupWindow::importProfile()
 {
 	InfoData = "";
 	QString importProfile =  QFileDialog::getOpenFileName(this,
-			appName + " - " + tr("Import Profile","this is a dialog title"), "/",
+			appName + " - " + tr("Import Profile","this is a dialog title"), SLASH,
 			appName + " " + tr("profile")+" (*.profile)");
 
 	if ( importProfile == "")	//if cancel is pressed at the file dialog, do nothing
@@ -784,7 +823,7 @@ void luckyBackupWindow::importProfile()
 	importprofile.setFileName(importProfile);
 
 	QString newProfileName = importProfile;
-	newProfileName = newProfileName.right(newProfileName.size() - newProfileName.lastIndexOf("/") - 1);
+	newProfileName = newProfileName.right(newProfileName.size() - newProfileName.lastIndexOf(SLASH) - 1);
 	newProfileName.chop(8);
 
 	QString newProfile = profileDir + newProfileName + ".profile";
@@ -837,7 +876,8 @@ void luckyBackupWindow::setLanguage(QAction *action)
 {
 	QString currentLocale = action -> data().toString();
 	transDir.setPath(relativeTransDir);
-	if (transDir.exists())
+    QStringList transContQm = transDir.entryList ( QStringList("luckybackup*.qm"), QDir::Files, QDir::NoSort); // list of .qm files inside transdir
+	if ( (transDir.exists()) && (!transContQm.isEmpty()) )
 		appTranslator.load(QString("luckybackup_") + currentLocale, relativeTransDir);
 	else 
 		appTranslator.load(QString("luckybackup_") + currentLocale, systemTransDir);
@@ -936,11 +976,13 @@ void luckyBackupWindow::add()
 		checkCurrentItem();
 		TotalOperations = ui.listWidget_operations -> count();		//set the TotalOperations to what it is now
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
 	}
 }
 
 //  modify ==========================================================================================================================================
 // Modifies an existing operation by calling the modifyDialog
+// Will also save the profile according to saveOrNot
 void luckyBackupWindow::modify()
 {
 	modifyOK = FALSE;
@@ -966,6 +1008,8 @@ void luckyBackupWindow::modify()
 			count++;
 		}
 	}
+	
+	QString oldTaskName = Operation[currentOperation] -> GetName();  // the original task name wil become handy in case it changes
 
 	//open the modify dialog and modify "Operation array" item at position currentOperation
  	modifyDialog modifydialog(currentOperation); 
@@ -974,16 +1018,23 @@ void luckyBackupWindow::modify()
 	if (modifyOK)		//if all went ok - modify existing operation
 	{
 		Qt::CheckState isIncluded = ui.listWidget_operations -> currentItem() -> checkState(); //get the include checkbox state
+        QString newTaskName = Operation[currentOperation] -> GetName();  // the new task name
 		ui.listWidget_operations -> takeItem(currentOperation);	//take out the selected item from the list
 									//insert a new one at the same position with the new name
-		ui.listWidget_operations -> insertItem(currentOperation, Operation[currentOperation] -> GetName());	
+		ui.listWidget_operations -> insertItem(currentOperation, newTaskName);	
 		ui.listWidget_operations -> setCurrentRow(currentOperation);		//highlight this row
 		ui.listWidget_operations -> currentItem() -> setCheckState(isIncluded); //set the include checkbox as it was
 		Operation[currentOperation] -> SetConnectRestore(tempConnect);		//set the connection to what it was
 		if (tempConnect != "")
-			Operation[connectPosition]->SetConnectRestore(Operation[currentOperation] -> GetName());
+			Operation[connectPosition]->SetConnectRestore(newTaskName);
 		checkCurrentItem();
-		savedProfile = FALSE;			//change profile status to "unsaved"
+		
+		// update all relevant snap .changes as well as log files if the task name changes
+        if (newTaskName != oldTaskName)
+            arrangeLogSnap(0,"rename",oldTaskName);
+        
+        if (saveOrNot)      // also save the current profile if saveOrNot is TRUE
+            saveCurrentProfile();     
 	}
 }
 
@@ -1000,6 +1051,7 @@ void luckyBackupWindow::remove()
 	}
 
 	QString tempConnect = Operation[currentOperation] -> GetConnectRestore();
+    QString oldTaskName = Operation[currentOperation] -> GetName();  // the original task name wil become handy in case it changes
 
 	textDialog textdialogQ ("QtQuestion", tr("Are you sure you want to remove the following task ??")+" <br>" +
  				(ui.listWidget_operations -> currentItem()) -> text(), this);
@@ -1044,6 +1096,10 @@ void luckyBackupWindow::remove()
 			}
 		}
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
+        
+        // add the deleted yask name to this list to be used when profile is saved
+        deletedTaskNames << oldTaskName;
 	}
 }
 
@@ -1088,6 +1144,7 @@ void luckyBackupWindow::moveUp()
 		ui.listWidget_operations -> setCurrentRow(currentOperation - 1);
 		
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
 	}
 }
 
@@ -1112,6 +1169,7 @@ void luckyBackupWindow::moveDown()
 		ui.listWidget_operations -> setCurrentRow(currentOperation + 1);
 
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
 	}
 }
 
@@ -1147,7 +1205,6 @@ void luckyBackupWindow::start()
 // Displays a new dialog to make a cron job for included operations
 void luckyBackupWindow::schedule()
 {
-	//open the modify dialog and create "Operation array" item at position currentOperation
  	scheduleDialog scheduledialog; 
 	scheduledialog.exec();
 
@@ -1158,13 +1215,31 @@ void luckyBackupWindow::schedule()
 	crontabUpdated = FALSE;		//this is set true each time the crontab is update
 }
 
+// email==========================================================================================================================================
+// Displays a new dialog to email report after a profile execution
+void luckyBackupWindow::email()
+{
+    emailDialog emaildialog; 
+    emaildialog.exec();
+
+    if (emaildialog.getGoOn() == 0)     // everything went ok
+    {
+        InfoData = tr("Email preferences have been <font color=green>updated successfully") + "</font>";
+        ui.textBrowser_info -> setText(InfoData);
+        
+        savedProfile = FALSE;           //change profile status to "unsaved"
+        ui.actionSave -> setEnabled(TRUE);
+    }
+    
+}
+
 // taskStateChanged =================================================================================================================================
 // Sets the profile state to unsaved if a task checkbox is changed
 void luckyBackupWindow::taskStateChanged()
 {
 	//theory (due to connections at luckybackwindow constructor):
 	//when an item is just clicked functions called: checkCurrentItem -> taskStateChanged
-	//when a checkbox state chenges functiond called: taskStateChanged -> checkCurrentItem -> taskStateChanged
+	//when a checkbox state changes functiond called: taskStateChanged -> checkCurrentItem -> taskStateChanged
 	if (!taskChanged)
 	{
 		if (taskClicked)
@@ -1175,7 +1250,10 @@ void luckyBackupWindow::taskStateChanged()
 	}
 
 	if ( (taskChanged) && (taskClicked) )
+    {
 		savedProfile = FALSE;			//change profile status to "unsaved"
+		ui.actionSave -> setEnabled(TRUE);
+    }
 
 	taskClicked = FALSE;
 	taskChanged = FALSE;
@@ -1191,7 +1269,7 @@ void luckyBackupWindow::checkCurrentItem()
 	CheckedData = "";
 	currentOperation = ui.listWidget_operations -> currentRow();
 	
-	if (currentOperation <0)	// to avoid segfault when nothing selected
+	if (currentOperation < 0)	// to avoid segfault when nothing selected
 		return;
 	
 	//first set  variables source & dest
