@@ -1,34 +1,35 @@
 /*-------------------------main.cpp------------------------------------------
     Main project is "luckyBackup"
     a backup and sync tool
-    project version	: 0.4.4
+    project version : 0.4.5
 
     ===============================================================================================================================
     ===============================================================================================================================
-	This file is part of "luckyBackup" project
-	Copyright 2008-2010, Loukas Avgeriou
-	luckyBackup is distributed under the terms of the GNU General Public License
-	luckyBackup is free software: you can redistribute it and/or modify
-	it under the terms of the GNU General Public License as published by
-	the Free Software Foundation, either version 3 of the License, or
-	(at your option) any later version.
+    This file is part of "luckyBackup" project
+    Copyright 2008-2011, Loukas Avgeriou
+    luckyBackup is distributed under the terms of the GNU General Public License
+    luckyBackup is free software: you can redistribute it and/or modify
+    it under the terms of the GNU General Public License as published by
+    the Free Software Foundation, either version 3 of the License, or
+    (at your option) any later version.
     
-	luckyBackup is distributed in the hope that it will be useful,
-	but WITHOUT ANY WARRANTY; without even the implied warranty of
-	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-	GNU General Public License for more details.
+    luckyBackup is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+    GNU General Public License for more details.
     
-	You should have received a copy of the GNU General Public License
-	along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
+    You should have received a copy of the GNU General Public License
+    along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
-    developer 		: luckyb 
-    last modified 		: 05 Sep 2010
+    developer       : luckyb 
+    last modified   : 12 Jan 2011
     ===============================================================================================================================
     ===============================================================================================================================
 */
 
-// just include the qt libraries needed, the main window header file
-// and show the main window or execute in command line mode
+// Perform various initial checks
+// include the qt libraries needed & the main window header file
+// show the main window or execute in command line mode
 
 #include <QApplication>
 #include <QTranslator>
@@ -40,7 +41,7 @@ int main(int argc, char *argv[])
 {
 	//arguments test
 	if (!argumentsTest(argc,argv))
-		return 1;		// error code1: something wrong with the command arguments - app fail to start
+		return 1;		// error code1: something wrong with the command arguments - app fail to start (or just --help or --version given as args)
 	
 	//profile validity check for console mode or gui-no profile specified (will use default)
 	if ( (runImmediately) && (!loadCurrentProfile()) )
