@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2010, Loukas Avgeriou
+     Copyright 2008-2011, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
      You should have received a copy of the GNU General Public License
      along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
- project version	: Please see "main.cpp" for project version
+ project version    : Please see "main.cpp" for project version
 
- developer 		: luckyb 
- last modified 		: 01 Sep 2010
+ developer          : luckyb 
+ last modified      : 12 Feb 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -48,17 +48,19 @@ manageDialog::manageDialog (QDialog *parent) : QDialog (parent)
 	sourceLast = "";
 
 	//fix source and dest
-	if (!source.endsWith("/"))	// this means task is of type "backup dir by name"
+	if (!source.endsWith(SLASH))	// this means task is of type "backup dir by name"
 	{
 		sourceLast = source;
-		if (sourceLast.contains(":"))	// this is normal for a remote directory
+		if ( (sourceLast.contains(":")) && (!OS2running) )	// this is normal for a remote directory - non OS2
 			sourceLast = sourceLast.right(source.size()-sourceLast.lastIndexOf(":")-1);	//this is the remote source dir without the remote pc
-		if (source.contains("/"))	// this is normal for a directory unless it is remote
-			sourceLast = sourceLast.right(source.size()-sourceLast.lastIndexOf("/")-1);	//this is the lowest dir of source
+		if (source.contains(SLASH))	// this is normal for a directory unless it is remote
+			sourceLast = sourceLast.right(source.size()-sourceLast.lastIndexOf(SLASH)-1);	//this is the lowest dir of source
 		
-		sourceLast.append("/");
-		source.append("/");
+		sourceLast.append(SLASH);
+		source.append(SLASH);
 		dest.append(sourceLast);
+        if (dest.endsWith(SLASH+SLASH))
+            dest.chop(1);
 	}
 
 	uiG.setupUi(this);
@@ -350,7 +352,7 @@ void manageDialog::SnapshotsListSelected()
 	else
 	{
 		CurrentSnapshotString = Operation[currentOperation] -> GetSnapshotsListItem (CurrentSnapshotNo);
-		CurrentSnapshotDirectory = dest + snapDefaultDir + CurrentSnapshotString + "/" + sourceLast;
+		CurrentSnapshotDirectory = dest + snapDefaultDir + CurrentSnapshotString + SLASH + sourceLast;
 		if (CurrentSnapshotString == "")	// if there is no execution time of the current snapshot
 			CurrentSnapshotString = "not available";
 	}
