@@ -4,7 +4,7 @@
 ===============================================================================================================================
 ===============================================================================================================================
      This file is part of "luckyBackup" project
-     Copyright 2008-2010, Loukas Avgeriou
+     Copyright 2008-2011, Loukas Avgeriou
      luckyBackup is distributed under the terms of the GNU General Public License
      luckyBackup is free software: you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published by
@@ -19,10 +19,10 @@
      You should have received a copy of the GNU General Public License
      along with luckyBackup.  If not, see <http://www.gnu.org/licenses/>.
 
- project version	: Please see "main.cpp" for project version
+ project version    : Please see "main.cpp" for project version
 
- developer 		: luckyb 
- last modified 		: 18 Oct 2010
+ developer          : luckyb 
+ last modified      : 16 Feb 2011
 ===============================================================================================================================
 ===============================================================================================================================
 */
@@ -53,7 +53,7 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
 	else
 	{
 		sourceLast = source;
-		sourceLast = sourceLast.right(source.size()-sourceLast.lastIndexOf("/",-2)-1);	//this is the lowest dir of source
+		sourceLast = sourceLast.right(source.size()-sourceLast.lastIndexOf(SLASH,-2)-1);	//this is the lowest dir of source
 	}
 	dest = DEST;		// the full path of the destination
 	time = Operation[currentOperation] -> GetSnapshotsListItem(currentSnap);
@@ -63,7 +63,7 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
 		timeReadable = time.mid(0,4) + "/" + time.mid(4,2) + "/" + time.mid(6,2) + " - " +
 					time.mid(8,2) + ":" + time.mid(10,2) + ":" + time.mid(12,2);	//QString
 
-	QDir snapSpecificDir(dest + snapDefaultDir + time + "/");
+	QDir snapSpecificDir(dest + snapDefaultDir + time + SLASH);
 	if (snapSpecificDir.exists())
 		snapSpecificDirExists = TRUE;
 	else
@@ -72,6 +72,10 @@ manageWizard::manageWizard (QString type, QString SOURCE, QString DEST,  int sna
 	// delete backup;if this are more than one snapshots available, set dir to delete as snapSpecificDir
 	if ((wizard_type == "deleteBackup") && (snapshotsNo > 1))
 		dest = snapSpecificDir.absolutePath();
+    if (OS2running)
+        dest.replace("/",SLASH);
+    if (dest.endsWith(SLASH+SLASH))
+        dest.chop(1);
 	
 	errorCount = 0 ;
 	errorsFound = 0;
@@ -337,8 +341,8 @@ void manageWizard::changeRestorePath()
 	if (newRestore != "")
 	{
 		//if the new restore dir does not end with /
-		if (!newRestore.endsWith("/"))
-			newRestore.append("/");
+		if (!newRestore.endsWith(SLASH))
+			newRestore.append(SLASH);
 		source = newRestore;
 	}
 	guiInitialize();
@@ -477,7 +481,7 @@ void manageWizard::calcCommandArgs()
 		commandArguments.append(dest);	// set new dest as source Argument  - as it was calculated at manageWizard
 	}
 	else
-		commandArguments.append(dest + snapDefaultDir + time + "/" + sourceLast);
+		commandArguments.append(dest + snapDefaultDir + time + SLASH + sourceLast);
 		
 	commandArguments.append(source);	// set new source as destination ...as it was calculated at manageWizard or changed by changeRestorePath
 }
