@@ -152,6 +152,7 @@ scheduleDialog::scheduleDialog (QDialog *parent) : QDialog (parent)
 				if (vString == "ScheduleSkipCritical")	tempSchedule	-> SetSkipCritical(v.toBool());
 				if (vString == "ScheduleConsoleMode")	tempSchedule	-> SetConsoleMode(v.toBool());
 				if (vString == "ScheduleAtReboot")	tempSchedule	-> SetReboot(v.toBool());
+                if (vString == "ScheduleAtRebootDelay")  tempSchedule    -> SetDelayReboot(v.toInt());
 
 				in>>v;	vString = v.toString();
 				if (vString!="current schedule end")
@@ -263,6 +264,7 @@ void scheduleDialog::schedulePressed()
 			v = "ScheduleSkipCritical";out << v;	v = Schedule[currentSchedule] -> GetSkipCritical();		out << v;
 			v = "ScheduleConsoleMode";out << v;	v = Schedule[currentSchedule] -> GetConsoleMode();		out << v;
 			v = "ScheduleAtReboot";	out << v;	v = Schedule[currentSchedule] -> GetReboot();			out << v;
+            v = "ScheduleAtRebootDelay"; out << v;   v = Schedule[currentSchedule] -> GetDelayReboot();           out << v;
 
 			v = "current schedule end";	out << v;
 			
@@ -408,6 +410,7 @@ void scheduleDialog::clearScheduleDetails()
 	uiS.comboBox_DayOfWeek -> setCurrentIndex(0);
 	uiS.spinBox_hour -> setValue(0);
 	uiS.spinBox_minute -> setValue(0);
+    uiS.spinBox_delayReboot -> setValue(3);
 	uiS.checkBox_skipCritical -> setCheckState(Qt::Checked);
 	uiS.checkBox_consoleMode -> setCheckState(Qt::Unchecked);
 	uiS.checkBox_reboot -> setCheckState(Qt::Unchecked);
@@ -428,6 +431,7 @@ void scheduleDialog::fillDetails()
 	uiS.comboBox_DayOfWeek -> setCurrentIndex(Schedule[currentSchedule] -> GetWeekDay());
 	uiS.spinBox_hour -> setValue(Schedule[currentSchedule] -> GetHour());
 	uiS.spinBox_minute -> setValue(Schedule[currentSchedule] -> GetMinute());
+    uiS.spinBox_delayReboot -> setValue(Schedule[currentSchedule] -> GetDelayReboot());
 	
 	if (Schedule[currentSchedule] -> GetSkipCritical())
 		uiS.checkBox_skipCritical -> setCheckState(Qt::Checked);
@@ -492,6 +496,7 @@ void scheduleDialog::okaySchedulePressed()
 	tempOp -> SetWeekDay (uiS.comboBox_DayOfWeek -> currentIndex());
 	tempOp -> SetHour (uiS.spinBox_hour -> value());
 	tempOp -> SetMinute (uiS.spinBox_minute -> value());
+    tempOp -> SetDelayReboot (uiS.spinBox_delayReboot -> value());
 	tempOp -> SetSkipCritical (uiS.checkBox_skipCritical -> isChecked());
 	tempOp -> SetConsoleMode (uiS.checkBox_consoleMode -> isChecked());
 	tempOp -> SetName (scheduleText(tempOp -> GetProfileName(),
@@ -648,7 +653,11 @@ void scheduleDialog::createCron()
 		while (currentSchedule < TotalSchedule)
 		{
 			if (Schedule[currentSchedule] -> GetReboot())			//append @reboot if checkbox selected
-				ScheduleLine.append("@reboot	");
+            {
+				ScheduleLine.append("@reboot    ");
+				if (Schedule[currentSchedule] -> GetDelayReboot() > 0 )
+                    ScheduleLine.append("sleep " + countStr.setNum(Schedule[currentSchedule] -> GetDelayReboot() * 60) +";    ");
+            }
 			else									// else append time-day eth
 			{
 				ScheduleLine.append(countStr.setNum(Schedule[currentSchedule] -> GetMinute()) + " ");	//minute
