@@ -4,7 +4,7 @@
 //===============================================================================================================================
 //===============================================================================================================================
 //     This file is part of "luckyBackup" project
-//     Copyright 2008-2010, Loukas Avgeriou
+//     Copyright 2008-2011, Loukas Avgeriou
 //     luckyBackup is distributed under the terms of the GNU General Public License
 //     luckyBackup is free software: you can redistribute it and/or modify
 //     it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 // project version	: Please see "main.cpp" for project version
 
 // developer 		: luckyb 
-// last modified 	: 19 Aug 2010
+// last modified 	: 12 Feb 2011
 //===============================================================================================================================
 //===============================================================================================================================
 
@@ -109,6 +109,16 @@ textDialog::textDialog (const QString type, const QString ReplaceInput, QWidget
 		uiT.pushButton_cancel -> setVisible(FALSE);
 		uiT.label_message 	-> setText(ReplaceInput);
 	}
+	if (type == "emailOutput")
+    {
+        uiT.lineEdit_userInput  -> setVisible(FALSE);
+        uiT.textEdit_userInput -> setVisible(TRUE);
+        this -> resize(640, 480);
+        uiT.label_message   -> setText(tr("eMail information"));
+        uiT.textEdit_userInput  -> setPlainText(ReplaceInput);
+        uiT.textEdit_userInput  -> setReadOnly(TRUE);
+        uiT.pushButton_cancel   -> setVisible(FALSE);
+    }
 	
 	// The next are used instead of standard Qt dialogs for translation reasons
 	if (type == "QtInformation")
